==> django_entity_event-0.4.4-py2.py3-none-any.whl: entity_event/tests/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TestFKModel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TestFKModel2',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
                ('fk', models.ForeignKey(to='tests.TestFKModel')),
                ('fk2', models.ForeignKey(to='tests.TestFKModel2')),
                ('fk_m2m', models.ManyToManyField(related_name='+', to='tests.TestFKModel')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
    ]

==> django_entity_event-2.0.0-py2.py3-none-any.whl: entity_event/tests/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TestFKModel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TestFKModel2',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.CharField(max_length=64)),
                ('fk', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='tests.TestFKModel')),
                ('fk2', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='tests.TestFKModel2')),
                ('fk_m2m', models.ManyToManyField(related_name='+', to='tests.TestFKModel')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
    ]
